@@ -1,6 +1,7 @@
 """Gevent loop customizations."""
 import asyncio
 from typing import Any
+
 import gevent.core
 
 
@@ -11,6 +12,6 @@ class Loop(gevent.core.loop):  # type: ignore
 
     def run_callback(self, *args: Any, **kwargs: Any) -> None:
         if self._aioloop_loop is None:
-            self._aioloop_loop = asyncio.get_event_loop()
+            self._aioloop_loop = asyncio.get_event_loop_policy().get_event_loop()
         gevent.spawn_later(0.0, self._aioloop_loop._run_once)  # type: ignore
         super().run_callback(*args, **kwargs)
