@@ -1,4 +1,4 @@
 from .formatter import GraphFormatter
 from .graph import DependencyGraph
 
-__all__ = ['DependencyGraph', 'GraphFormatter']
+__all__ = ["DependencyGraph", "GraphFormatter"]
