@@ -541,7 +541,7 @@ def cry(
         thread = tmap.get(tid)
         if thread:
             if thread.ident == current_thread.ident:
-                loop = asyncio.get_event_loop()
+                loop = asyncio.get_event_loop_policy().get_event_loop()
             else:
                 loop = getattr(thread, "loop", None)
             print(f"THREAD {thread.name}", file=file)  # noqa: T003
@@ -669,7 +669,7 @@ class flight_recorder(ContextManager, LogSeverityMixin):
         self.id = next(self._id_source)
         self.logger = logger
         self.timeout = want_seconds(timeout)
-        self.loop = loop or asyncio.get_event_loop()
+        self.loop = loop or asyncio.get_event_loop_policy().get_event_loop()
         self.started_at_date = None
         self.enabled_by = None
         self.exit_stack = ExitStack()
